package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Objects;
import org.apache.bcel.Const;
import org.apache.bcel.util.BCELComparator;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/Constant.class */
public abstract class Constant implements Cloneable, Node {
    private static BCELComparator bcelComparator = new BCELComparator() { // from class: org.apache.bcel.classfile.Constant.1
        public boolean equals(Object o1, Object o2) {
            Constant THIS = (Constant) o1;
            Constant THAT = (Constant) o2;
            return Objects.equals(THIS.toString(), THAT.toString());
        }

        public int hashCode(Object o) {
            Constant THIS = (Constant) o;
            return THIS.toString().hashCode();
        }
    };

    @java.lang.Deprecated
    protected byte tag;

    @Override // org.apache.bcel.classfile.Node
    public abstract void accept(Visitor visitor);

    public abstract void dump(DataOutputStream dataOutputStream) throws IOException;

    public static BCELComparator getComparator() {
        return bcelComparator;
    }

    public static Constant readConstant(DataInput dataInput) throws IOException, ClassFormatException {
        byte b = dataInput.readByte();
        switch (b) {
            case JavaClass.HEAP /* 1 */:
                return ConstantUtf8.getInstance(dataInput);
            case JavaClass.FILE /* 2 */:
            case 13:
            case 14:
            default:
                throw new ClassFormatException("Invalid byte tag in constant pool: " + ((int) b));
            case JavaClass.ZIP /* 3 */:
                return new ConstantInteger(dataInput);
            case 4:
                return new ConstantFloat(dataInput);
            case 5:
                return new ConstantLong(dataInput);
            case 6:
                return new ConstantDouble(dataInput);
            case 7:
                return new ConstantClass(dataInput);
            case 8:
                return new ConstantString(dataInput);
            case 9:
                return new ConstantFieldref(dataInput);
            case 10:
                return new ConstantMethodref(dataInput);
            case 11:
                return new ConstantInterfaceMethodref(dataInput);
            case 12:
                return new ConstantNameAndType(dataInput);
            case 15:
                return new ConstantMethodHandle(dataInput);
            case 16:
                return new ConstantMethodType(dataInput);
            case 17:
                return new ConstantDynamic(dataInput);
            case 18:
                return new ConstantInvokeDynamic(dataInput);
            case 19:
                return new ConstantModule(dataInput);
            case 20:
                return new ConstantPackage(dataInput);
        }
    }

    public static void setComparator(BCELComparator comparator) {
        bcelComparator = comparator;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public Constant(byte tag) {
        this.tag = tag;
    }

    public Object clone() {
        try {
            return super.clone();
        } catch (CloneNotSupportedException e) {
            throw new Error("Clone Not Supported");
        }
    }

    public Constant copy() {
        try {
            return (Constant) super.clone();
        } catch (CloneNotSupportedException e) {
            return null;
        }
    }

    public boolean equals(Object obj) {
        return bcelComparator.equals(this, obj);
    }

    public final byte getTag() {
        return this.tag;
    }

    public int hashCode() {
        return bcelComparator.hashCode(this);
    }

    public String toString() {
        return Const.getConstantName(this.tag) + "[" + ((int) this.tag) + "]";
    }
}
